#ifndef _EFL_UI_LAYOUT_PART_BG_EO_H_
#define _EFL_UI_LAYOUT_PART_BG_EO_H_

#ifndef _EFL_UI_LAYOUT_PART_BG_EO_CLASS_TYPE
#define _EFL_UI_LAYOUT_PART_BG_EO_CLASS_TYPE

typedef Eo Efl_Ui_Layout_Part_Bg;

#endif

#ifndef _EFL_UI_LAYOUT_PART_BG_EO_TYPES
#define _EFL_UI_LAYOUT_PART_BG_EO_TYPES


#endif
#ifdef EFL_BETA_API_SUPPORT
/** Elementary layout internal part background class
 *
 * @ingroup Efl_Ui_Layout_Part_Bg
 */
#define EFL_UI_LAYOUT_PART_BG_CLASS efl_ui_layout_part_bg_class_get()

EWAPI const Efl_Class *efl_ui_layout_part_bg_class_get(void);
#endif /* EFL_BETA_API_SUPPORT */

#endif
